define(['underscore', 'jquery', 'backbone', 'marionette', 'services/social', 'services/payments', 'controllers/quests', 'controllers/push-notifications', 'controllers/server', 'controllers/screens', 'controllers/menu', 'controllers/short-info', 'controllers/user-events', 'controllers/modal', 'controllers/tutorial', 'controllers/shop', 'fastclick', 'views/components/swipe-2-refresh', 'models/translation', 'models/patchedViews', 'models/level-access-config'], function(_, $, Backbone, Marionette, SocialService, PaymentsService, QuestsController, PushNotificationsController, ServerController, ScreensController, MenuController, ShortInfoController, EventsController, ModalController, TutorialController, ShopController, FastClick, Swipe2Refresh, Translations, PatchedViews, LevelAccessConfig) {
  var app;
  app = new Marionette.Application({
    regions: {
      'canvas': '#js-canvas',
      'menuRegion': '#js-menu',
      'shortInfoRegion': '#js-short-info',
      'modalRegion': '#js-modal-container'
    }
  });
  app.addInitializer(function(options) {
    var startLogin, _ref;
    app.userId = 0;
    app.config = options;
    app.version = options.version.value;
    app.translations = new Translations([], {
      app: app
    });
    app.patchedViews = new PatchedViews([], {
      app: app
    });
    app.patchedViews.fetch();
    setTimeout((function() {
      return $('#startup-loader').hide();
    }), 15000);
    window.__scrollPointerOffHover = null;
    window.addEventListener('scroll', function() {
      clearTimeout(window.__scrollPointerOffHover);
      if (!document.body.classList.contains('disable-hover')) {
        document.body.classList.add('disable-hover');
      }
      return window.__scrollPointerOffHover = setTimeout((function() {
        return document.body.classList.remove('disable-hover');
      }), 800);
    }, false);
    app.tr = function(variable, locale) {
      if (locale == null) {
        locale = null;
      }
      return app.translations.tr(variable, locale);
    };
    app.shortInfo = new ShortInfoController({
      app: app
    });
    app.modalDialog = new ModalController({
      app: app
    });
    app.screens = new ScreensController({
      app: app
    });
    app.server = new ServerController({
      app: app
    });
    app.menu = new MenuController({
      app: app
    });
    app.userEvents = new EventsController({
      app: app
    });
    app.pushNotifications = new PushNotificationsController({
      app: app
    });
    app.tutorial = new TutorialController({
      app: app
    });
    app.shop = new ShopController({
      app: app
    });
    app.quests = new QuestsController({
      app: app
    });
    app.levelAccessConfig = new LevelAccessConfig();
    app.levelAccessConfig.url = app.config.serverURLProtocol + '://' + app.config.serverURL + '/levels/level_access/get.json';
    app.levelAccessConfig.fetch();
    app.isAvailable = function(level, action) {
      return app.levelAccessConfig.isAvailable(level, action);
    };
    app.availableFrom = function(action) {
      return app.levelAccessConfig.availableFrom(action);
    };
    app.socialService = new SocialService(app.config.social, app.config.serverURL, app.config.serverURLProtocol);
    app.paymentsService = new PaymentsService(app, app.config.payments, app.config.serverURL, app.config.serverURLProtocol);
    if (app.paymentsService.isEnabled()) {
      app.paymentsService.setPendingPurchaseCallbacks(function(data) {
        return app.screens.modal('common/success-popup', {
          msg: app.tr("Purchase completed"),
          currency: 'vgold',
          amount: data.amount
        });
      }, null);
    }
    app.gaEnabled = false;
    if (app.config.googleAnalyticsEnabled) {
      require(['ga'], function(ga) {
        app.gaEnabled = true;
        app.ga = ga;
        app.ga('create', app.config.googleAnalyticsTrackingCode, 'none');
        app.ga('set', 'checkProtocolTask', null);
        app.ga('set', 'checkStorageTask', null);
        if (app.config.serverURLProtocol === 'https') {
          app.ga('set', 'forceSSL', true);
        }
        return app.ga('send', 'pageview');
      });
    }
    app.setUserId = function(userId) {
      app.userId = userId;
      if (app.config.googleAnalyticsEnabled && app.ga) {
        return app.ga('set', 'userId', app.userId);
      }
    };

    /*
    		This id debug hook to redirrect to specified screen right after the page is loaded.
    			localStorage.redirect = 'screen id' # to specify screen to be redirected to
    
    			delete localStorage.redirect # to reset
     */
    if ((app.config.locked != null) && app.config.locked) {
      app.screens.main('app_locked');
    } else if (app.config.debug && (localStorage.redirect != null)) {
      app.server.reauth({
        success: function(data) {
          app.userId = data.userId;
          app.menu.init();
          app.shortInfo.init();
          return app.screens.main(localStorage.redirect);
        },
        error: function() {
          return app.screens.main('login');
        }
      });
    } else if ((localStorage.auth != null) || (localStorage.auth_token != null)) {
      app.screens.main('auto_login');
    } else {
      startLogin = function() {
        return app.screens.main('login');
      };
      if (((_ref = window.navigator) != null ? _ref.globalization : void 0) != null) {
        window.navigator.globalization.getLocaleName(function(locale) {
          var localization;
          localization = (function() {
            switch (locale.value) {
              case "pl-PL":
                return "pol";
              case "ru-RU":
                return "rus";
              default:
                return "eng";
            }
          })();
          return app.translations.setLocaleAndFetch(localization, startLogin);
        }, function() {
          return app.translations.setLocaleAndFetch('eng', startLogin);
        });
      } else {
        app.translations.setLocaleAndFetch('eng', startLogin);
      }
    }
    Backbone.history.start();
    window.app = app;
    if (app.config.debug) {
      require.onResourceLoad = function(context, map) {
        if (map.id !== 'app' && map.id !== 'text') {
          return require.undef(map.id);
        }
      };
    }
    document.addEventListener("backbutton", (function(_this) {
      return function() {
        if (!$('body').hasClass('no-swipe')) {
          return _this.trigger("device:back");
        }
      };
    })(this));
    window.addEventListener("native.keyboardshow", (function(_this) {
      return function(event) {
        return _this.trigger("keyboard:show", event.keyboardHeight);
      };
    })(this));
    window.addEventListener("native.keyboardhide", (function(_this) {
      return function(event) {
        return _this.trigger("keyboard:hide");
      };
    })(this));
    this.listenTo(app.server, 'app:locked', (function(_this) {
      return function() {
        return app.screens.main('app_locked');
      };
    })(this));
    this.listenTo(app.server, 'app:need_reauth', (function(_this) {
      return function() {
        return app.screens.main('app_need_reauth');
      };
    })(this));
    FastClick.attach(document.body);
    app.loader = document.getElementById('ajax-loader');
    app.showLoader = function() {
      return app.loader.style.display = 'block';
    };
    app.hideLoader = function() {
      return app.loader.style.display = 'none';
    };
    app.__s2r = new Swipe2Refresh(document.getElementById('js-short-info'), function() {
      return app.vent.trigger('swipe:reload');
    });
    return app.translations.on('sync', function() {
      var _ref1, _ref2;
      if (((_ref1 = app.menu) != null ? _ref1.view : void 0) != null) {
        app.menu.view.render();
      }
      if (((_ref2 = app.shortInfo) != null ? _ref2.view : void 0) != null) {
        return app.shortInfo.view.render();
      }
    });
  });
  app.getVersion = function() {
    return app.version;
  };
  app.getDeviceOs = function() {
    var os;
    try {
      os = device.platform.toLowerCase();
    } catch (_error) {
      os = 'unknown';
    }
    return os;
  };
  return app;
});
