define(['app', 'views/item-view', 'underscore', 'text!templates/business/capital.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    data: {
      corporationInfo: {
        pointer: 'business.corporationInfo',
        corporationId: function() {
          return this.options.corporationId;
        }
      }
    },
    events: {
      'click .js-goto-company': 'gotoCompany',
      'click .js-not-manager-alert': 'notManagerAlert',
      'click .js-goto-management': 'gotoManagement',
      'click .js-goto-corporation-storage': 'gotoCorporationStorage',
      'click .js-goto-shareholders': 'gotoShareholders',
      'click .js-create-company': 'createCompany',
      'click .js-invest': 'invest'
    },
    notManagerAlert: function(event) {
      return app.screens.modal('common/info-popup', {
        msg: app.tr("You are not a company's manager")
      });
    },
    gotoCompany: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.quests.doIfCompleted('social_passport', function() {
        return app.screens.dialog('corporative_companies/common', {
          companyId: companyId
        });
      });
    },
    gotoManagement: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/management', {
        corporationId: corporationId
      });
    },
    gotoCorporationStorage: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/corp-storage', {
        corporationId: corporationId
      });
    },
    gotoShareholders: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/shareholders', {
        corporationId: corporationId
      });
    },
    createCompany: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.quests.doIfCompleted('social_passport', function() {
        return app.screens.dialog('business/create-company', {
          corporationId: corporationId
        });
      });
    },
    invest: function(event) {
      var corporationId, vd_balance, vg_balance;
      this.lockUI();
      corporationId = this.options.corporationId;
      vd_balance = this._data.corporationInfo.currentCorporation.vd_balance;
      vg_balance = this._data.corporationInfo.currentCorporation.vg_balance;
      return app.quests.doIfCompleted('social_passport', function() {
        return app.screens.dialog('business/corp-invest', {
          corporationId: corporationId,
          vd_balance: vd_balance,
          vg_balance: vg_balance
        });
      });
    }
  });
});
