define(['app', 'views/item-view', 'underscore', 'text!templates/business/corp-invest.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    events: {
      'click .o-switcher': 'changeCurrency',
      'change .js-amount': 'changeAmount',
      'click .js-apply': 'addFunds'
    },
    changeCurrency: function(event) {
      $(event.currentTarget).toggleClass('o-switcher--active');
      this.$el.find('.js-currency').toggleClass('o-icon--vdollar o-icon--vgold');
      return this.$el.find('.js-apply').toggleClass('c-btn--green c-btn--yellow');
    },
    changeAmount: function(event) {
      var amount;
      amount = this.$el.find('.js-amount').val();
      if (isNaN(amount)) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("The amount may consist only of digits")
        });
      } else {
        return this.$el.find('.saved-amount').html(amount);
      }
    },
    addFunds: function(event) {
      var amount, corporationId, currency;
      this.lockUI();
      amount = this.$el.find('.js-amount').val();
      corporationId = this.options.corporationId;
      currency = this.$el.find('.o-switcher').hasClass('o-switcher--active') ? 'vgold' : 'vdollars';
      if (amount === "") {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("Specify the sum")
        });
      } else if (isNaN(amount)) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("The amount can only consist of digits")
        });
      } else if (amount <= 0) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("The amount must be greater than zero")
        });
      } else {
        if (currency === "vdollars") {
          return app.server.business.corporationInvestVd({
            corporationId: corporationId,
            amount: amount,
            success: function(data) {
              return app.screens.modal('common/success-popup', {
                msg: data.setFlash[0].msg || app.tr("Account refilled"),
                amount: amount
              }, app.screens.back());
            },
            error: function(data) {
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              });
            }
          });
        } else {
          return app.server.business.corporationInvestVg({
            corporationId: corporationId,
            amount: amount,
            success: function(data) {
              return app.screens.modal('common/success-popup', {
                msg: data.setFlash[0].msg || app.tr("Account refilled"),
                amount: amount,
                currency: "vgold"
              }, app.screens.back());
            },
            error: function(data) {
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              });
            }
          });
        }
      }
    }
  });
});
