define(['app', 'views/item-view', 'underscore', 'text!templates/business/corp-storage.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    events: {
      'click .js-goto-capital': 'gotoCapital',
      'click .js-goto-management': 'gotoManagement',
      'click .js-goto-shareholders': 'gotoShareholders',
      'click .js-goto-buying': 'gotoBuying',
      'click .js-goto-selling': 'gotoSelling'
    },
    data: {
      corporationStorage: {
        pointer: 'business.corporationStorage',
        corporationId: function() {
          return this.options.corporationId;
        }
      },
      corporationInfo: {
        pointer: 'business.corporationInfo',
        corporationId: function() {
          return this.options.corporationId;
        }
      }
    },
    gotoCapital: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = event.currentTarget.getAttribute('data-corporation-id');
      return app.screens.tab('business/capital', {
        corporationId: corporationId
      });
    },
    gotoManagement: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = event.currentTarget.getAttribute('data-corporation-id');
      return app.screens.tab('business/management', {
        corporationId: corporationId
      });
    },
    gotoShareholders: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = event.currentTarget.getAttribute('data-corporation-id');
      return app.screens.tab('business/shareholders', {
        corporationId: corporationId
      });
    },
    gotoBuying: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = event.currentTarget.getAttribute('data-corporation-id');
      return app.quests.doIfCompleted('social_passport', function() {
        return app.screens.dialog('trade-center/trade-center-corporation', {
          corporationId: corporationId
        });
      });
    },
    gotoSelling: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = event.currentTarget.getAttribute('data-corporation-id');
      if (this._data.corporationStorage.storage.length === 0) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("Your storage is empty")
        });
      } else {
        return app.quests.doIfCompleted('social_passport', function() {
          return app.screens.dialog('trade-center/sell-item-corporation', {
            corporationId: corporationId
          });
        });
      }
    }
  });
});
