define(['app', 'views/item-view', 'underscore', 'text!templates/business/management.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    data: {
      corporationInfo: {
        pointer: 'business.corporationInfo',
        corporationId: function() {
          return this.options.corporationId;
        }
      },
      corporationVotes: {
        pointer: 'business.corporationVotes',
        corporationId: function() {
          return this.options.corporationId;
        }
      }
    },
    events: {
      'click .js-goto-capital': 'gotoCapital',
      'click .js-goto-corporation-storage': 'gotoCorporationStorage',
      'click .js-goto-shareholders': 'gotoShareholders',
      'click .js-goto-proposals': 'gotoProposals',
      'click .js-vote-positive': 'votePositive',
      'click .js-vote-negative': 'voteNegative'
    },
    gotoCapital: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/capital', {
        corporationId: corporationId
      });
    },
    gotoCorporationStorage: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/corp-storage', {
        corporationId: corporationId
      });
    },
    gotoShareholders: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/shareholders', {
        corporationId: corporationId
      });
    },
    gotoProposals: function(event) {
      this.lockUI();
      return app.quests.doIfCompleted('social_passport', (function(_this) {
        return function() {
          var corporationId;
          corporationId = _this.options.corporationId;
          return app.screens.dialog('business/initiative', {
            corporationId: corporationId
          });
        };
      })(this));
    },
    votePositive: function(event) {
      this.lockUI();
      return app.quests.doIfCompleted('social_passport', (function(_this) {
        return function() {
          var corporationId, solutionId;
          solutionId = event.currentTarget.getAttribute('data-solution-id');
          corporationId = _this.options.corporationId;
          return app.server.business.proposeVotePositive({
            solutionId: solutionId,
            corporationId: corporationId,
            success: function(data) {
              return app.screens.modal('common/success-popup', {
                msg: data.setFlash[0].msg || app.tr("Action was successful")
              });
            },
            error: function(data) {
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              });
            }
          });
        };
      })(this));
    },
    voteNegative: function(event) {
      this.lockUI();
      return app.quests.doIfCompleted('social_passport', (function(_this) {
        return function() {
          var corporationId, solutionId;
          solutionId = event.currentTarget.getAttribute('data-solution-id');
          corporationId = _this.options.corporationId;
          return app.server.business.proposeVoteNegative({
            solutionId: solutionId,
            corporationId: corporationId,
            success: function(data) {
              return app.screens.modal('common/success-popup', {
                msg: data.setFlash[0].msg || app.tr("Action was successful")
              });
            },
            error: function(data) {
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              });
            }
          });
        };
      })(this));
    }
  });
});
