define(['app', 'views/item-view', 'underscore', 'text!templates/business/storage.tmpl', 'views/components/currency', 'views/components/clusterize-helper'], function(app, ItemView, _, template, formatCurrency, ClusterizeHelper) {
  return ItemView.extend({
    template: template,
    data: {
      companyInfo: {
        pointer: 'business.companyInfo',
        companyId: function() {
          return this.options.companyId;
        }
      },
      effects: {
        pointer: 'business.company.effects',
        companyId: function() {
          return this.options.companyId;
        }
      },
      storage: {
        pointer: 'business.storage',
        companyId: function() {
          return this.options.companyId;
        }
      },
      inventory: {
        pointer: 'inventory.unequipped'
      }
    },
    events: {
      'click .js-goto-employees': 'gotoEmployees',
      'click .js-goto-common': 'gotoCommon',
      'click .js-goto-selling': 'gotoSelling',
      'click .js-goto-buying': 'gotoBuying',
      'click .js-settings': 'settings',
      'click .js-inventory-item': 'transferItemToCompany',
      'click .js-storage-item': 'transferItemToUser',
      'click .js-expand-storage': 'expandStorage',
      'click .js-effects': 'showEffects'
    },
    settings: function(event) {
      var companyId, menu;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      menu = new Backbone.Collection([
        {
          id: 1,
          title: 'Rename company'
        }, {
          id: 2,
          title: 'Transfer company to corporation'
        }
      ]);
      return app.screens.dialog('common/select-dialog', {
        collection: menu,
        callback: (function(_this) {
          return function(itemId) {
            if (itemId === 1) {
              return app.screens.dialog('business/rename-company', {
                companyId: companyId
              });
            } else {
              return app.screens.dialog('business/transfer-company', {
                companyId: companyId
              });
            }
          };
        })(this)
      });
    },
    gotoEmployees: function(event) {
      var companyId;
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.tab('business/employees', {
        companyId: companyId
      });
    },
    gotoCommon: function(event) {
      var companyId;
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.tab('business/common', {
        companyId: companyId
      });
    },
    gotoSelling: function(event) {
      var companyId;
      companyId = event.currentTarget.getAttribute('data-company-id');
      if (this._data.storage.storage.length === 0) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("Your storage is empty")
        });
      } else {
        return app.screens.dialog('trade-center/sell-item-company', {
          companyId: companyId
        });
      }
    },
    gotoBuying: function(event) {
      var companyId;
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('trade-center/trade-center-business', {
        companyId: companyId
      });
    },
    transferItemToCompany: function(event) {
      var companyId, itemId, itemTypeId, number;
      this.lockUI();
      itemTypeId = event.currentTarget.getAttribute('data-itemType-id');
      itemId = event.currentTarget.getAttribute('data-item-id');
      number = event.currentTarget.getAttribute('data-quantity');
      companyId = this.options.companyId;
      return app.screens.modal('business/move-item-to-company-popup', {
        itemId: itemId,
        number: number,
        callback: (function(_this) {
          return function(quantity) {
            return app.server.business.moveItemsToCompany({
              companyId: companyId,
              itemTypeId: itemTypeId,
              quantity: quantity,
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg || app.tr("Well done")
                }, app.screens.back());
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                }, app.screens.back());
              }
            });
          };
        })(this)
      });
    },
    transferItemToUser: function(event) {
      var companyId, itemTypeId, number;
      this.lockUI();
      itemTypeId = event.currentTarget.getAttribute('data-itemType-id');
      number = event.currentTarget.getAttribute('data-quantity');
      companyId = this.options.companyId;
      return app.screens.modal('business/move-item-to-user-popup', {
        itemTypeId: itemTypeId,
        number: number,
        callback: (function(_this) {
          return function(quantity) {
            return app.server.business.moveItemsToUser({
              companyId: companyId,
              itemTypeId: itemTypeId,
              quantity: quantity,
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg || app.tr("Well done")
                }, app.screens.back());
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                }, app.screens.back());
              }
            });
          };
        })(this)
      });
    },
    expandStorage: function(event) {
      var companyId;
      this.lockUI();
      companyId = this.options.companyId;
      if (this._data.storage.next_storage_level.max_prod != null) {
        return app.screens.modal('common/confirmation-popup', {
          msg: this._data.storage.next_storage_level.confirmation,
          callback: (function(_this) {
            return function() {
              return app.server.business.upStorageLevel({
                companyId: companyId,
                success: function(data) {
                  return app.screens.modal('common/success-popup', {
                    msg: data.setFlash[0].msg || app.tr("Warehouse increased")
                  });
                },
                error: function(data) {
                  return app.screens.modal('common/info-popup', {
                    msg: data.setFlash[0].msg || app.tr("Something went wrong")
                  });
                }
              });
            };
          })(this)
        });
      } else {
        return app.screens.modal('common/info-popup', {
          msg: this._data.storage.next_storage_level.confirmation || app.tr("Something went wrong")
        });
      }
    },
    onDomRefresh: function() {
      [].forEach.call(this.el.querySelectorAll('.js-currency'), function(el) {
        return el.innerHTML = formatCurrency(el.innerHTML);
      });
      return ClusterizeHelper(this.$el, 30, true);
    },
    showEffects: function(event) {
      var companyId;
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('maria/city-effects', {
        companyId: companyId
      });
    }
  });
});
