define(['app', 'views/item-view', 'underscore', 'text!templates/business/employees.tmpl', 'views/components/currency'], function(app, ItemView, _, template, formatCurrency) {
  return ItemView.extend({
    template: template,
    data: {
      сompanyWorkersInfo: {
        pointer: 'business.сompanyWorkersInfo',
        companyId: function() {
          return this.options.companyId;
        }
      },
      effects: {
        pointer: 'business.company.effects',
        companyId: function() {
          return this.options.companyId;
        }
      },
      companyInfo: {
        pointer: 'business.companyInfo',
        companyId: function() {
          return this.options.companyId;
        }
      }
    },
    events: {
      'click .js-goto-employees-list': 'gotoEmployeesList',
      'click .js-goto-foreign-workers': 'gotoForeignWorkers',
      'click .js-goto-recruitment': 'gotoRecruitment',
      'click .js-goto-storage': 'gotoStorage',
      'click .js-goto-common': 'gotoCommon',
      'click .js-up-level': 'upLevel',
      'click .js-goto-change-manager': 'gotoChangeManager',
      'click .js-settings': 'settings',
      'click .js-effects': 'showEffects'
    },
    onDomRefresh: function() {
      return [].forEach.call(this.el.querySelectorAll('.js-currency'), function(el) {
        return el.innerHTML = formatCurrency(el.innerHTML);
      });
    },
    settings: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('business/settings', {
        companyId: companyId
      });
    },
    gotoCommon: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.tab('corporative_companies/common', {
        companyId: companyId
      });
    },
    gotoStorage: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.tab('corporative_companies/storage', {
        companyId: companyId
      });
    },
    gotoEmployeesList: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('business/employees-list', {
        companyId: companyId
      });
    },
    gotoForeignWorkers: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('business/hiring-migrants', {
        companyId: companyId
      });
    },
    gotoRecruitment: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('business/recruitment', {
        companyId: companyId
      });
    },
    gotoChangeManager: function(event) {
      var companyId, managerId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      managerId = event.currentTarget.getAttribute('data-manager-id');
      return app.screens.dialog('corporative_companies/change-manager', {
        companyId: companyId,
        managerId: managerId
      });
    },
    upLevel: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.modal('common/confirmation-popup', {
        msg: app.tr('Do you want to upgrade the workers limit?'),
        callback: (function(_this) {
          return function(count) {
            return app.server.business.corporative_company.upLevel({
              companyId: companyId,
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg || app.tr("Settings saved")
                });
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    },
    showEffects: function(event) {
      var companyId;
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('maria/city-effects', {
        companyId: companyId
      });
    }
  });
});
