define(['app', 'views/item-view', 'underscore', 'text!templates/corporative_companies/storage.tmpl', 'views/components/currency', 'views/components/clusterize-helper'], function(app, ItemView, _, template, formatCurrency, ClusterizeHelper) {
  return ItemView.extend({
    template: template,
    data: {
      companyInfo: {
        pointer: 'business.companyInfo',
        companyId: function() {
          return this.options.companyId;
        }
      },
      effects: {
        pointer: 'business.company.effects',
        companyId: function() {
          return this.options.companyId;
        }
      },
      storage: {
        pointer: 'business.storage',
        companyId: function() {
          return this.options.companyId;
        }
      },
      inventory: {
        pointer: 'business.corporationStorage.byCompany',
        companyId: function() {
          return this.options.companyId;
        }
      }
    },
    events: {
      'click .js-goto-employees': 'gotoEmployees',
      'click .js-goto-common': 'gotoCommon',
      'click .js-goto-selling': 'gotoSelling',
      'click .js-goto-buying': 'gotoBuying',
      'click .js-settings': 'settings',
      'click .js-inventory-item': 'transferItemToCompany',
      'click .js-storage-item': 'transferItemToCorporation',
      'click .js-expand-storage': 'expandStorage',
      'click .js-effects': 'showEffects'
    },
    settings: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('business/settings', {
        companyId: companyId
      });
    },
    gotoEmployees: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.tab('corporative_companies/employees', {
        companyId: companyId
      });
    },
    gotoCommon: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.tab('corporative_companies/common', {
        companyId: companyId
      });
    },
    gotoSelling: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      if (this._data.storage.storage.length === 0) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("Your storage is empty")
        });
      } else {
        return app.screens.dialog('trade-center/sell-item-company', {
          companyId: companyId
        });
      }
    },
    gotoBuying: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('trade-center/trade-center-business', {
        companyId: companyId
      });
    },
    transferItemToCompany: function(event) {
      var companyId, itemTypeId, number;
      this.lockUI();
      itemTypeId = event.currentTarget.getAttribute('data-itemType-id');
      number = event.currentTarget.getAttribute('data-quantity');
      companyId = this.options.companyId;
      return app.screens.modal('corporative_companies/move-item-to-company-popup', {
        itemTypeId: itemTypeId,
        number: number,
        callback: (function(_this) {
          return function(quantity) {
            return app.server.business.moveItemsFromCorporation({
              companyId: companyId,
              itemTypeId: itemTypeId,
              quantity: quantity,
              success: function(data) {
                var _ref;
                return app.screens.modal('common/success-popup', {
                  msg: (data != null ? (_ref = data.setFlash[0]) != null ? _ref.msg : void 0 : void 0) || app.tr("Well done")
                }, app.screens.back());
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                }, app.screens.back());
              }
            });
          };
        })(this)
      });
    },
    transferItemToCorporation: function(event) {
      var companyId, itemTypeId, number;
      this.lockUI();
      itemTypeId = event.currentTarget.getAttribute('data-itemType-id');
      number = event.currentTarget.getAttribute('data-quantity');
      companyId = this.options.companyId;
      return app.screens.modal('corporative_companies/move-item-to-corporation-popup', {
        itemTypeId: itemTypeId,
        number: number,
        callback: (function(_this) {
          return function(quantity) {
            return app.server.business.moveItemsToCorporation({
              companyId: companyId,
              itemTypeId: itemTypeId,
              quantity: quantity,
              success: function(data) {
                var _ref;
                return app.screens.modal('common/success-popup', {
                  msg: (data != null ? (_ref = data.setFlash[0]) != null ? _ref.msg : void 0 : void 0) || app.tr("Well done")
                }, app.screens.back());
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                }, app.screens.back());
              }
            });
          };
        })(this)
      });
    },
    expandStorage: function(event) {
      var companyId;
      this.lockUI();
      companyId = this.options.companyId;
      if (this._data.storage.next_storage_level.max_prod != null) {
        return app.screens.modal('common/confirmation-popup', {
          msg: this._data.storage.next_storage_level.confirmation,
          callback: (function(_this) {
            return function() {
              return app.server.business.corporative_company.upStorageLevel({
                companyId: companyId,
                success: function(data) {
                  return app.screens.modal('common/success-popup', {
                    msg: data.setFlash[0].msg || app.tr("Warehouse increased")
                  });
                },
                error: function(data) {
                  return app.screens.modal('common/info-popup', {
                    msg: data.setFlash[0].msg || app.tr("Something went wrong")
                  });
                }
              });
            };
          })(this)
        });
      } else {
        return app.screens.modal('common/info-popup', {
          msg: this._data.storage.next_storage_level.confirmation || app.tr("Something went wrong")
        });
      }
    },
    onDomRefresh: function() {
      [].forEach.call(this.el.querySelectorAll('.js-currency'), function(el) {
        return el.innerHTML = formatCurrency(el.innerHTML);
      });
      return ClusterizeHelper(this.$el, 30, true);
    },
    showEffects: function(event) {
      var companyId;
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('maria/city-effects', {
        companyId: companyId
      });
    }
  });
});
