var __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

define(['app', 'views/item-view', 'underscore', 'text!templates/house.tmpl', 'views/components/currency', 'views/components/strings-helper'], function(app, ItemView, _, template, formatCurrency, StringsHelper) {
  var HouseView;
  HouseView = (function(_super) {
    __extends(HouseView, _super);

    function HouseView() {
      return HouseView.__super__.constructor.apply(this, arguments);
    }

    HouseView.prototype.template = template;

    HouseView.prototype.data = {
      info: 'house.info',
      userFurniture: 'inventory.furniture'
    };

    HouseView.prototype.events = {
      'click .js-buy': 'buyHouse',
      'click .js-put-furniture': 'putFurniture',
      'click .js-remove-furniture': 'removeFurniture',
      'click .js-levelup-furniture-slots': 'levelUpFurnitureSLots'
    };

    HouseView.prototype.preprocessData = function(data) {
      var arrId, item, userHome, _ref, _ref1;
      _ref = data['userFurniture']['furniture']['itemsArray'];
      for (arrId in _ref) {
        item = _ref[arrId];
        item.id = item.UserItem.id;
        item.title = item.ItemType.name;
      }
      this.userItemsCollection = new Backbone.Collection(data['userFurniture']['furniture']['itemsArray']);
      _ref1 = data['info']['userHomes'];
      for (arrId in _ref1) {
        userHome = _ref1[arrId];
        userHome.itemsCollection = new Backbone.Collection(userHome['HomeItem']);
      }
      return data;
    };

    HouseView.prototype.buyHouse = function(event) {
      var homeTypeId, msg;
      this.lockUI();
      homeTypeId = event.currentTarget.getAttribute('data-homeTypeId');
      msg = StringsHelper.replace({
        '{{item}}': this._data.info.homeTypeOffers[homeTypeId].UserHomeType.name,
        '{{price}}': this._data.info.homeTypeOffers[homeTypeId].UserHomeType.price + this._data.info.homeTypeOffers[homeTypeId].UserHomeType.currency
      }, app.tr("Do you want to buy {{item}} per {{price}} ?"));
      return app.screens.modal('common/confirmation-popup', {
        msg: msg,
        callback: (function(_this) {
          return function(count) {
            return app.server.house.buy({
              homeTypeId: homeTypeId,
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg
                });
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    };

    HouseView.prototype.putFurniture = function(event) {
      var homeId, placeSlot;
      this.lockUI();
      if (this.userItemsCollection.length === 0) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("You have no furniture in the inventory.")
        });
      } else {
        placeSlot = event.currentTarget.getAttribute('data-slot');
        homeId = event.currentTarget.getAttribute('data-home-id');
        return app.screens.dialog('common/select-dialog', {
          collection: this.userItemsCollection,
          callback: (function(_this) {
            return function(itemId) {
              return app.server.house.putFurniture({
                placeSlot: placeSlot,
                itemId: itemId,
                homeId: homeId
              });
            };
          })(this)
        });
      }
    };

    HouseView.prototype.removeFurniture = function(event) {
      var homeId, placeSlot;
      this.lockUI();
      placeSlot = event.currentTarget.getAttribute('data-slot');
      homeId = event.currentTarget.getAttribute('data-home-id');
      return app.screens.modal('common/confirmation-popup', {
        msg: "Are you sure you want to remove this furniture housing ?",
        callback: (function(_this) {
          return function() {
            return app.server.house.removeFurniture({
              placeSlot: placeSlot,
              homeId: homeId,
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg
                });
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    };

    HouseView.prototype.levelUpFurnitureSLots = function(event) {
      var UserHomeId;
      this.lockUI();
      UserHomeId = event.currentTarget.getAttribute('data-home-id');
      return app.screens.modal('common/confirmation-popup', {
        msg: app.tr('Do you want to upgrade the furniture slots?'),
        callback: (function(_this) {
          return function() {
            return app.server.house.levelUpFurnitureSlots({
              UserHomeId: UserHomeId,
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg || app.tr("Ok")
                });
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    };

    HouseView.prototype.onDomRefresh = function() {
      return [].forEach.call(this.el.querySelectorAll('.js-currency'), function(el) {
        return el.innerHTML = formatCurrency(el.innerHTML);
      });
    };

    return HouseView;

  })(ItemView);
  return HouseView;
});
