var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

define(['app', 'views/item-view', 'underscore', 'text!templates/inventory/popup.tmpl', 'text!templates/inventory/item.tmpl', 'moment'], function(app, ItemView, _, template, itemTemplate, moment) {
  var ItemPopupView;
  ItemPopupView = (function(_super) {
    __extends(ItemPopupView, _super);

    function ItemPopupView() {
      this.onDataLoaded = __bind(this.onDataLoaded, this);
      return ItemPopupView.__super__.constructor.apply(this, arguments);
    }

    ItemPopupView.prototype.template = template;

    ItemPopupView.prototype.itemTemplate = itemTemplate;

    ItemPopupView.prototype.required = ['itemId'];

    ItemPopupView.prototype.data = {
      item: {
        pointer: 'inventory.itemInfo',
        itemId: function() {
          return this.options.itemId;
        }
      }
    };

    ItemPopupView.prototype.events = {
      'click .js-put-on': 'putItemOn',
      'click .js-put-off': 'putItemOff',
      'click .js-use': 'useItem',
      'click .js-eat': 'eatItem',
      'click .js-throw': 'throwItem'
    };

    ItemPopupView.prototype.initialize = function(options) {
      ItemPopupView.__super__.initialize.apply(this, arguments);
      return this.itemTemplate = _.template(this.itemTemplate);
    };

    ItemPopupView.prototype.preprocessData = function(data) {
      if (data.item.itemInfo.ItemType.type === 'receipt') {
        data.item.equippable = false;
        data.item.usable = false;
        data.item.eatable = false;
      } else {
        data.item.equippable = this.isItemEquippable(data.item);
        data.item.usable = this.isItemUsable(data.item);
        data.item.eatable = this.isItemEatable(data.item);
      }
      return data;
    };

    ItemPopupView.prototype.putItemOn = function(event) {
      var item, itemId, slotId;
      this.lockUI();
      item = this._data.item;
      itemId = item.currentItem.UserItem.id;
      slotId = this.chooseSlotToPutOn(this._data.item);
      return app.server.inventory.putOn({
        itemId: itemId,
        slotId: slotId,
        success: (function(_this) {
          return function(data) {
            app.vent.trigger('inventory:item_equipped', {
              data: item
            });
            return app.screens.back();
          };
        })(this)
      });
    };

    ItemPopupView.prototype.putItemOff = function(event) {
      var item, itemId;
      this.lockUI();
      item = this._data.item;
      itemId = item.currentItem.UserItem.id;
      return app.server.inventory.putOff({
        itemId: itemId,
        success: (function(_this) {
          return function(data) {
            app.vent.trigger('inventory:item_unequipped', {
              data: item
            });
            if (data && data.storage) {
              app.vent.trigger('inventory:inventory_changed', {
                data: data.storage
              });
            }
            return app.screens.back();
          };
        })(this)
      });
    };

    ItemPopupView.prototype.useItem = function(event) {
      var item, itemId;
      this.lockUI();
      item = this._data.item;
      itemId = item.currentItem.UserItem.id;
      return app.server.inventory.useForm({
        itemId: itemId,
        success: (function(_this) {
          return function(data) {
            if (!data.error) {
              if ((_this._data.item.itemInfo.ItemType.special != null) && _this._data.item.itemInfo.ItemType.special > 0) {
                return app.server.inventory.useSpecial({
                  itemId: itemId,
                  success: function(data) {
                    app.vent.trigger('inventory:special_item_used', {
                      data: item
                    });
                    if (data && data.storage) {
                      app.vent.trigger('inventory:inventory_changed', {
                        data: data.storage
                      });
                    }
                    return app.screens.close(function() {
                      return app.screens.modal('common/success-popup', {
                        msg: data.setFlash[0].msg || app.tr("Item received")
                      });
                    });
                  },
                  error: function(data) {
                    return app.screens.back();
                  }
                });
              } else {
                if (!data.empty) {
                  return app.screens.close(function() {
                    return app.screens.modal('inventory/select', {
                      itemId: itemId
                    });
                  });
                } else {
                  return app.server.inventory.use({
                    itemId: itemId,
                    cityId: -1,
                    typeId: -1,
                    success: function(data) {
                      app.vent.trigger('inventory:item_used', {
                        data: item
                      });
                      if (data && data.storage) {
                        app.vent.trigger('inventory:inventory_changed', {
                          data: data.storage
                        });
                      }
                      return app.screens.close(function() {
                        return app.screens.modal('common/success-popup', {
                          msg: data.setFlash[0].msg || app.tr("Item received")
                        });
                      });
                    },
                    error: function(data) {
                      return app.screens.close(function() {
                        return app.screens.modal('common/info-popup', {
                          msg: data.setFlash[0].msg || app.tr("Something went wrong!")
                        });
                      });
                    }
                  });
                }
              }
            }
          };
        })(this),
        error: (function(_this) {
          return function(data) {
            return app.screens.back();
          };
        })(this)
      });
    };

    ItemPopupView.prototype.eatItem = function(event) {
      var item, itemId;
      this.lockUI();
      item = this._data.item;
      itemId = item.currentItem.UserItem.id;
      return app.server.inventory.eat({
        itemId: itemId,
        success: (function(_this) {
          return function(data) {
            app.vent.trigger('inventory:item_eaten', {
              data: item
            });
            if (data && data.storage) {
              app.vent.trigger('inventory:inventory_changed', {
                data: data.storage
              });
            }
            return app.screens.back();
          };
        })(this),
        error: (function(_this) {
          return function() {
            return app.screens.back();
          };
        })(this)
      });
    };

    ItemPopupView.prototype.throwItem = function(event) {
      this.lockUI();
      return app.screens.modal('common/confirmation-popup', {
        msg: app.tr('Do you want to throw this item away?'),
        callback: (function(_this) {
          return function(count) {
            var itemId;
            itemId = _this._data.item.currentItem.UserItem.id;
            return app.screens.back(function() {
              return app.server.inventory.remove({
                itemId: itemId,
                success: (function(_this) {
                  return function(data) {
                    app.vent.trigger('inventory:item_thrown', {
                      data: data
                    });
                    if (data && data.storage) {
                      app.vent.trigger('inventory:inventory_changed', {
                        data: data.storage
                      });
                    }
                    return app.screens.modal('common/success-popup', {
                      msg: data.setFlash[0].msg || app.tr("Item deleted")
                    });
                  };
                })(this)
              });
            });
          };
        })(this)
      });
    };

    ItemPopupView.prototype.chooseSlotToPutOn = function(item) {
      var slotId, slots, slotsOccupied, _i, _j, _len, _len1, _ref, _ref1;
      slots = (_ref = this.classOrTypeToSlotId[item.itemInfo.ItemType.type]) != null ? _ref : this.classOrTypeToSlotId[item.itemInfo.ItemType["class"]];
      slotsOccupied = {};
      _ref1 = this.options.inventory;
      for (_i = 0, _len = _ref1.length; _i < _len; _i++) {
        item = _ref1[_i];
        slotsOccupied[item.UserItem.equipped_slot] = true;
      }
      for (_j = 0, _len1 = slots.length; _j < _len1; _j++) {
        slotId = slots[_j];
        if (slotsOccupied[slotId] == null) {
          return slotId;
        }
      }
      return slots[0];
    };

    ItemPopupView.prototype.isItemEquippable = function(item) {
      var _ref;
      return !item.itemInfo.ItemType.can_use && (((_ref = this.classOrTypeToSlotId[item.itemInfo.ItemType.type]) != null ? _ref : this.classOrTypeToSlotId[item.itemInfo.ItemType["class"]]) != null);
    };

    ItemPopupView.prototype.isItemEatable = function(item) {
      return item.itemInfo.ItemType.type === 'food';
    };

    ItemPopupView.prototype.isItemUsable = function(item) {
      return item.itemInfo.ItemType.can_use;
    };

    ItemPopupView.prototype.onDataLoaded = function(data) {
      data.itemDescriptionString = this.itemTemplate(data.item.itemInfo);
      return ItemPopupView.__super__.onDataLoaded.call(this, data);
    };

    ItemPopupView.prototype.classOrTypeToSlotId = {
      'head_items': ['head_inventory'],
      'pants_items': ['pants_inventory'],
      'bracelet_items': ['bracelet_inventory'],
      'torso_items': ['torso_inventory'],
      'boots_items': ['boots_inventory'],
      'first_weapon_items': ['first_weapon_inventory', 'second_weapon_inventory'],
      'ring_items': ['first_ring_inventory', 'second_ring_inventory'],
      'ammunition': ['quick_inventory_1', 'quick_inventory_2', 'quick_inventory_3'],
      'special': ['quick_inventory_1', 'quick_inventory_2', 'quick_inventory_3'],
      'first_aid_kit': ['quick_inventory_1', 'quick_inventory_2', 'quick_inventory_3'],
      'flag': ['quick_inventory_1', 'quick_inventory_2', 'quick_inventory_3'],
      'bio_generator': ['quick_inventory_1', 'quick_inventory_2', 'quick_inventory_3']
    };

    return ItemPopupView;

  })(ItemView);
  return ItemPopupView;
});
