var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

define(['app', 'views/item-view', 'underscore', 'text!templates/job.tmpl'], function(app, ItemView, _, template) {
  var JobView;
  JobView = (function(_super) {
    __extends(JobView, _super);

    function JobView() {
      this.initialize = __bind(this.initialize, this);
      return JobView.__super__.constructor.apply(this, arguments);
    }

    JobView.prototype.template = template;

    JobView.prototype.data = {
      'currentWork': 'work.current',
      'info': 'user.info.profession'
    };

    JobView.prototype.events = {
      'click .js-resign': 'resignFromJob',
      'click .js-work': 'work',
      'click .c-btn-group__button': 'changeEnergy'
    };

    JobView.prototype.changeEnergy = function(event) {
      var activeStateClass, btn, buttons, disabledStateClass, el, _i, _len;
      btn = event.currentTarget;
      buttons = btn.parentNode.querySelectorAll('.c-btn-group__button');
      activeStateClass = 'c-btn-group__button--active';
      disabledStateClass = 'c-btn-group__button--disabled';
      if (!$(btn).hasClass(disabledStateClass)) {
        for (_i = 0, _len = buttons.length; _i < _len; _i++) {
          el = buttons[_i];
          if (el.classList) {
            el.classList.remove(activeStateClass);
          } else {
            el.activeStateClass = el.activeStateClass.replace(new RegExp('(^|\\b)' + activeStateClass.split(' ').join('|') + '(\\b|$)', 'gi'), ' ');
          }
        }
        if (btn.classList) {
          btn.classList.add(activeStateClass);
        } else {
          btn.activeStateClass += ' ' + activeStateClass;
        }
        return this.calculateSallary();
      }
    };

    JobView.prototype.initialize = function(options) {
      this.options = options;
      this.listenTo(app.userEvents, "energy:updated", this.updateEnergyField);
      this.listenTo(app.userEvents, "popup:closed", this.setMaxButton);
      if ((this.options.activeEnergy != null) === false) {
        this.options.activeEnergy = 50;
      }
      this.setMaxButton();
      return JobView.__super__.initialize.call(this, this.options);
    };


    /*
    			This method triggers then energy is updated
     */

    JobView.prototype.updateEnergyField = function(newEnergy) {
      this.invalidateCacheAndReload();
      return this.buttonsEnergyState();
    };

    JobView.prototype.setMaxButton = function() {
      var btn, btnEnergyValue, buttons, maxValue, valuesArr, _i, _len, _results;
      buttons = this.el.querySelectorAll('.c-btn-group--energy .c-btn-group__button');
      valuesArr = this.buttonsEnergyState();
      maxValue = Math.max.apply(this, valuesArr);
      _results = [];
      for (_i = 0, _len = buttons.length; _i < _len; _i++) {
        btn = buttons[_i];
        btnEnergyValue = parseInt(btn.querySelector('.js-energy-value').innerHTML);
        if (btnEnergyValue === maxValue) {
          $(btn).addClass('c-btn-group__button--active');
          _results.push(this.options.activeEnergy = maxValue);
        } else {
          _results.push($(btn).removeClass('c-btn-group__button--active'));
        }
      }
      return _results;
    };


    /*
    			Set state for energy buttons depends on energy value
     */

    JobView.prototype.buttonsEnergyState = function() {
      var btn, btnEnergyValue, buttons, experienceEl, redZone, valuesArr, _i, _len, _ref;
      if (((_ref = this._data) != null ? _ref.info : void 0) != null) {
        buttons = this.el.querySelectorAll('.c-btn-group--energy .c-btn-group__button');
        redZone = parseInt(this._data.info.user.User.energy);
        experienceEl = this.el.querySelector('.js-experience-value');
        valuesArr = [0];
        this.maxValue = 0;
        for (_i = 0, _len = buttons.length; _i < _len; _i++) {
          btn = buttons[_i];
          btnEnergyValue = parseInt(btn.querySelector('.js-energy-value').innerHTML);
          if (btnEnergyValue > redZone) {
            $(btn).addClass('c-btn-group__button--disabled');
          } else {
            $(btn).removeClass('c-btn-group__button--disabled');
            valuesArr.push(btnEnergyValue);
            if (btnEnergyValue > this.maxValue) {
              this.maxValue = btnEnergyValue;
            }
          }
        }
        return valuesArr;
      }
    };

    JobView.prototype.resignFromJob = function(event) {
      var msg, self, workerId;
      self = this;
      workerId = event.currentTarget.getAttribute('data-worker-id');
      msg = app.tr('Are you sure you want to quit your job?');
      return app.screens.modal('common/confirmation-popup', {
        msg: msg,
        callback: function() {
          return self._resignFromJob(workerId);
        }
      });
    };

    JobView.prototype._resignFromJob = function(workerId) {
      this.lockUI();
      return app.server.work.current.resign({
        workerId: workerId,
        success: function(data) {
          return app.screens.modal('common/success-popup', {
            msg: data.setFlash[0].msg,
            callback: function() {
              return app.vent.trigger('job:fired', {
                data: data
              });
            }
          });
        },
        error: function(data) {
          return app.screens.modal('common/info-popup', {
            msg: data.setFlash[0].msg || app.tr("Something went wrong")
          });
        }
      });
    };

    JobView.prototype.work = function(event) {
      var energy;
      this.lockUI();
      energy = parseInt(this.$el.find('.c-btn-group__button--active .js-energy-value').text());
      if ((this.maxValue != null) && this.maxValue < energy) {
        energy = this.maxValue;
        this.setMaxButton();
      }
      this.options.activeEnergy = energy;
      if (isNaN(energy)) {
        app.screens.modal('common/info-popup', {
          msg: app.tr("Not enough energy")
        });
        return;
      }
      return app.server.work.work({
        companyId: this._data.currentWork.company_id,
        energy: energy,
        success: (function(_this) {
          return function(data) {
            var options;
            options = {
              data: data,
              repeat: {
                method: _this.work,
                context: _this,
                event: event
              }
            };
            app.vent.trigger('job:worked', {
              data: data
            });
            return app.screens.modal('job/job-done', options);
          };
        })(this),
        error: function(data) {
          return app.screens.modal('common/info-popup', {
            msg: data.setFlash[0].msg || app.tr("Something went wrong")
          });
        }
      });
    };

    JobView.prototype.calculateSallary = function() {
      if (this.el.querySelector('.c-btn-group--energy')) {
        this.energyValueEl = this.$('.c-btn-group__button--active .js-energy-value');
        this.energy = this.energyValueEl.html();
        this.salaryValueEl = this.el.querySelector('.js-salary-value');
        return this.salaryValueEl.innerHTML = parseInt((0.8 + 0.2 * this._data.currentWork.level) * this.energy * (+this._data.currentWork.salary));
      }
    };


    /*
    			Center cloud
     */

    JobView.prototype.centerCloud = function() {
      var $cloud, $container;
      if ($('.c-cloud').length > 0) {
        $cloud = $('.c-cloud');
        $container = $('.js-canvas');
        return $cloud.css('margin-top', ($container.height() / 2 - $cloud.height() / 2) / 2);
      }
    };

    JobView.prototype.onDomRefresh = function() {
      this.centerCloud();
      this.calculateSallary();
      if (this.el.querySelectorAll('.c-btn-group--energy .c-btn-group__button').length > 0) {
        return this.buttonsEnergyState();
      }
    };

    return JobView;

  })(ItemView);
  return JobView;
});
