define(['app', 'views/item-view', 'underscore', 'text!templates/maria/bills.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    data: {
      bills: 'cityHall.bills',
      itemsBills: 'cityHall.itemsBills',
      userStatus: 'user.status',
      evolutionVote: 'cityHall.evolutionVotes',
      areasTakeoverBills: 'cityHall.areasTakeover.bills'
    },
    events: {
      'click .js-vote-for': 'voteForBill',
      'click .js-vote-against': 'voteAgainstBill',
      'click .js-vote-for-takeover': 'voteForTakeover',
      'click .js-vote-against-takeover': 'voteAgainstTakeover',
      'click .js-vote-for-itemBill': 'voteForItemBill',
      'click .js-vote-against-itemBill': 'voteAgainstItemBill',
      'click .js-evolution-vote-for': 'voteForEvolution',
      'click .js-evolution-vote-against': 'voteAgainstEvolution',
      'click .js-new-law': 'newLaw'
    },
    voteForBill: function(event) {
      var billId;
      this.lockUI();
      billId = event.currentTarget.getAttribute('data-bill-id');
      return app.server.cityHall.voteForBill({
        billId: billId,
        success: (function(_this) {
          return function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Your voice has been accepted")
            });
          };
        })(this)
      });
    },
    voteAgainstBill: function(event) {
      var billId;
      this.lockUI();
      billId = event.currentTarget.getAttribute('data-bill-id');
      return app.server.cityHall.voteAgainstBill({
        billId: billId,
        success: (function(_this) {
          return function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Your voice has been accepted")
            });
          };
        })(this)
      });
    },
    voteForTakeover: function(event) {
      var billId;
      this.lockUI();
      billId = event.currentTarget.getAttribute('data-bill-id');
      return app.server.cityHall.areasTakeover.vote({
        billId: billId,
        vote: 'positive',
        success: (function(_this) {
          return function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Your voice has been accepted")
            });
          };
        })(this)
      });
    },
    voteAgainstTakeover: function(event) {
      var billId;
      this.lockUI();
      billId = event.currentTarget.getAttribute('data-bill-id');
      return app.server.cityHall.areasTakeover.vote({
        billId: billId,
        vote: 'negative',
        success: (function(_this) {
          return function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Your voice has been accepted")
            });
          };
        })(this)
      });
    },
    voteForItemBill: function(event) {
      var billId;
      this.lockUI();
      billId = event.currentTarget.getAttribute('data-itemBill-id');
      return app.server.cityHall.voteForItemBill({
        billId: billId,
        success: (function(_this) {
          return function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Your voice has been accepted")
            });
          };
        })(this)
      });
    },
    voteAgainstItemBill: function(event) {
      var billId;
      this.lockUI();
      billId = event.currentTarget.getAttribute('data-itemBill-id');
      return app.server.cityHall.voteAgainstItemBill({
        billId: billId,
        success: (function(_this) {
          return function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Your voice has been accepted")
            });
          };
        })(this)
      });
    },
    evolutionVote: function(event, vote) {
      var cityEvolutionId;
      this.lockUI();
      cityEvolutionId = event.currentTarget.getAttribute('data-evolution-id');
      return app.server.cityHall.evolutionVote({
        cityEvolutionId: cityEvolutionId,
        vote: vote,
        success: (function(_this) {
          return function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Your voice has been accepted")
            });
          };
        })(this)
      });
    },
    voteForEvolution: function(event) {
      return this.evolutionVote(event, 1);
    },
    voteAgainstEvolution: function(event) {
      return this.evolutionVote(event, 0);
    },
    newLaw: function(event) {
      this.lockUI();
      return app.server.military.at.checkActiveTakeover({
        success: (function(_this) {
          return function(data) {
            return app.screens.dialog('maria/new-bill');
          };
        })(this)
      });
    }
  });
});
