define(['app', 'views/item-view', 'underscore', 'text!templates/maria/company.tmpl', 'views/components/energy-slider', 'views/components/currency'], function(app, ItemView, _, template, EnergySlider, formatCurrency) {
  return ItemView.extend({
    template: template,
    data: {
      companyInfo: {
        pointer: 'business.companyInfo',
        companyId: function() {
          return this.options.companyId;
        }
      },
      effects: {
        pointer: 'business.company.effects',
        companyId: function() {
          return this.options.companyId;
        }
      },
      info: 'user.info.short'
    },
    events: {
      'click .js-goto-employees': 'gotoEmployees',
      'click .js-goto-storage': 'gotoStorage',
      'click .js-add-funds': 'addFunds',
      'click .js-take-funds': 'takeFunds',
      'click .js-settings': 'settings',
      'click .js-change-prod': 'changeProd',
      'click .js-effects': 'showEffects'
    },
    addFunds: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('maria/add-funds', {
        companyId: companyId
      });
    },
    takeFunds: function(event) {
      var companyId, withdrawTax;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      withdrawTax = event.currentTarget.getAttribute('data-withdraw-tax');
      return app.screens.dialog('maria/withdraw', {
        companyId: companyId,
        withdrawTax: withdrawTax
      });
    },
    gotoEmployees: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.tab('maria/employees', {
        companyId: companyId
      });
    },
    gotoStorage: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.tab('maria/company-storage', {
        companyId: companyId
      });
    },
    onDomRefresh: function() {
      return [].forEach.call(this.el.querySelectorAll('.js-currency'), function(el) {
        return el.innerHTML = formatCurrency(el.innerHTML);
      });
    },
    settings: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('business/settings', {
        companyId: companyId
      });
    },
    changeProd: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('business/change-production', {
        companyId: companyId
      });
    },
    showEffects: function(event) {
      var companyId;
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('maria/city-effects', {
        companyId: companyId
      });
    }
  });
});
