define(['app', 'views/item-view', 'underscore', 'text!templates/maria/storage.tmpl', 'views/components/currency', 'views/components/clusterize-helper'], function(app, ItemView, _, template, formatCurrency, ClusterizeHelper) {
  return ItemView.extend({
    template: template,
    data: {
      userStatus: 'user.status',
      cityItemProposals: 'cityHall.cityItemProposals',
      storage: 'cityHall.storage'
    },
    events: {
      'click .js-goto-buying': 'gotoBuying',
      'click .js-lost-settings': 'lotsSettings',
      'click .js-delete-lot': 'deleteLot',
      'click .js-pause-lot': 'pauseLot',
      'click .js-play-lot': 'playLot'
    },
    gotoBuying: function(event) {
      this.lockUI();
      return app.quests.doIfCompleted('social_passport', function() {
        return app.screens.dialog('trade-center/trade-center-maria');
      });
    },
    lotsSettings: function(event) {
      var cityItemProposalId;
      return cityItemProposalId = event.currentTarget.getAttribute('data-lot-id');
    },
    deleteLot: function(event) {
      var cityItemProposalId;
      this.lockUI();
      cityItemProposalId = event.currentTarget.getAttribute('data-lot-id');
      return app.screens.modal('common/confirmation-popup', {
        msg: app.tr('Do you want to delete the purchase?'),
        callback: (function(_this) {
          return function(count) {
            return app.server.cityHall.deleteCityItemProposal({
              cityItemProposalId: cityItemProposalId,
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg || app.tr("Purchase has been deleted")
                });
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    },
    pauseLot: function(event) {
      var cityItemProposalId;
      this.lockUI();
      cityItemProposalId = event.currentTarget.getAttribute('data-lot-id');
      return app.screens.modal('common/confirmation-popup', {
        msg: app.tr('Are you sure you want to suspend the purchase?'),
        callback: (function(_this) {
          return function(count) {
            return app.server.cityHall.pauseCityItemProposal({
              cityItemProposalId: cityItemProposalId,
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg || app.tr("Purchase is paused")
                });
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    },
    playLot: function(event) {
      var cityItemProposalId;
      this.lockUI();
      cityItemProposalId = event.currentTarget.getAttribute('data-lot-id');
      return app.screens.modal('common/confirmation-popup', {
        msg: app.tr('D you want to launch the purchase?'),
        callback: (function(_this) {
          return function(count) {
            return app.server.cityHall.pauseCityItemProposal({
              cityItemProposalId: cityItemProposalId,
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg || app.tr("Purchase is active")
                });
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    },
    onDomRefresh: function() {
      [].forEach.call(this.el.querySelectorAll('.js-currency'), function(el) {
        return el.innerHTML = formatCurrency(el.innerHTML);
      });
      return ClusterizeHelper(this.$el, 30, true);
    }
  });
});
