define(['app', 'views/item-view', 'underscore', 'text!templates/business/withdraw.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    events: {
      'click .js-apply': 'takeFunds',
      'change .amount': 'changeAmount'
    },
    changeAmount: function(event) {
      var amount;
      amount = this.$el.find('.amount').val();
      if (isNaN(amount)) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("The amount may consist only of digits")
        });
      } else {
        return this.$el.find('.withdraw').html(Math.round(amount * this.options.withdrawTax / 100));
      }
    },
    takeFunds: function(event) {
      var amount, companyId;
      this.lockUI();
      amount = this.$el.find('.amount').val();
      companyId = this.options.companyId;
      if (amount === "") {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("Specify the sum")
        });
      } else if (isNaN(amount)) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("The amount can only consist of digits")
        });
      } else if (amount <= 0) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("The amount must be greater than zero")
        });
      } else {
        return app.server.cityHall.takeFunds({
          companyId: companyId,
          amount: amount,
          success: function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Account refilled")
            });
          },
          error: function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Something went wrong")
            });
          }
        });
      }
    }
  });
});
