define(['app', 'views/item-view', 'underscore', 'text!templates/parties/create-party.tmpl', 'jquery'], function(app, ItemView, _, template, $) {
  return ItemView.extend({
    template: template,
    className: 'no-bg-image',
    events: {
      'click .js-create-party': 'createParty',
      'click .js-select-image': 'selectAndUploadImage'
    },
    data: {
      price: 'party.create.price'
    },
    selectAndUploadImage: (function(_this) {
      return function(event) {
        var uploadPhoto;
        uploadPhoto = function(imageURI) {
          var ft, options, to;
          options = new FileUploadOptions;
          options.fileKey = 'file';
          options.fileName = imageURI.substr(imageURI.lastIndexOf('/') + 1);
          options.mimeType = 'image/jpeg';
          options.chunkedMode = false;
          to = encodeURI(app.config.serverURLProtocol + '://' + app.config.serverURL + '/parties/upload.json');
          ft = new FileTransfer;
          return ft.upload(imageURI, to, function(r) {
            var json;
            json = JSON.parse(r.response);
            if ((json != null ? json.image : void 0) != null) {
              return $('#party-logo').attr('src', app.config.serverURLProtocol + '://' + app.config.serverURL + '/attachments/partylogo/' + json.image);
            }
          }, function(error) {
            return app.screens.modal('common/info-popup', {
              msg: app.tr("Something went wrong")
            });
          }, options);
        };
        return navigator.camera.getPicture(uploadPhoto, (function(message) {
          return app.screens.modal('common/info-popup', {
            msg: app.tr("Image is not chosen")
          });
        }), {
          quality: 50,
          destinationType: navigator.camera.DestinationType.FILE_URI,
          sourceType: navigator.camera.PictureSourceType.PHOTOLIBRARY
        });
      };
    })(this),
    createParty: function(event) {
      var description, logo, name;
      this.lockUI();
      name = this.$el.find('.name').val();
      description = this.$el.find('#description').val();
      logo = this.$el.find('#party-logo').attr('src');
      if (name === "") {
        app.screens.modal('common/info-popup', {
          msg: app.tr("Specify the name")
        });
        return;
      }
      if (description === "") {
        app.screens.modal('common/info-popup', {
          msg: app.tr("Specify the party's motto")
        });
        return;
      }
      if (logo === "" || logo === '../images/icons/icon-plus-2.png') {
        app.screens.modal('common/info-popup', {
          msg: app.tr("Upload the logo")
        });
        return;
      }
      return app.server.party.create({
        name: name,
        description: description,
        logo: logo,
        success: function(data) {
          return app.screens.modal('common/success-popup', {
            msg: data.setFlash[0].msg || app.tr("Company was created")
          }, app.screens.back());
        },
        error: function(data) {
          return app.screens.modal('common/info-popup', {
            msg: data.setFlash[0].msg || app.tr("Something went wrong")
          });
        }
      });
    }
  });
});
