define(['app', 'views/item-view', 'underscore', 'text!templates/parties/manage.tmpl', 'jquery'], function(app, ItemView, _, template, $) {
  return ItemView.extend({
    template: template,
    data: {
      info: {
        pointer: 'party.info'
      }
    },
    events: {
      'click .js-apply': 'apply',
      'click .js-select-image': 'selectAndUploadImage',
      'click .o-switcher-small': 'toggleSwither'
    },
    toggleSwither: function(event) {
      return $(event.currentTarget).toggleClass('o-switcher-small--active');
    },
    selectAndUploadImage: (function(_this) {
      return function(event) {
        var uploadPhoto;
        uploadPhoto = function(imageURI) {
          var ft, options, to;
          options = new FileUploadOptions;
          options.fileKey = 'file';
          options.fileName = imageURI.substr(imageURI.lastIndexOf('/') + 1);
          options.mimeType = 'image/jpeg';
          options.chunkedMode = false;
          to = 'http://' + app.config.serverURL + '/parties/upload.json';
          ft = new FileTransfer;
          return ft.upload(imageURI, to, function(r) {
            var json;
            json = JSON.parse(r.response);
            if ((json != null ? json.image : void 0) != null) {
              return $('#party-logo').attr('src', 'http://' + app.config.serverURL + '/attachments/partylogo/' + json.image);
            }
          }, function(error) {
            return alert('An error has occurred: Code = ' + error.code);
          }, options);
        };
        return navigator.camera.getPicture(uploadPhoto, (function(message) {
          return alert('get picture failed');
        }), {
          quality: 50,
          destinationType: navigator.camera.DestinationType.FILE_URI,
          sourceType: navigator.camera.PictureSourceType.PHOTOLIBRARY
        });
      };
    })(this),
    apply: function(event) {
      var auto, description, logo, name;
      this.lockUI();
      name = this.$el.find('#name').val();
      description = this.$el.find('#description').val();
      auto = this.$el.find('#manage').hasClass('o-switcher-small--active') ? 1 : 0;
      logo = this.$el.find('#party-logo').attr('src');
      if (name === "") {
        app.screens.modal('common/info-popup', {
          msg: app.tr("Specify the name")
        });
        return;
      }
      if (description === "") {
        app.screens.modal('common/info-popup', {
          msg: app.tr("Specify the party's motto")
        });
        return;
      }
      if (logo === "") {
        app.screens.modal('common/info-popup', {
          msg: app.tr("Upload the logo")
        });
        return;
      }
      return app.server.party.update({
        name: name,
        description: description,
        logo: logo,
        auto: auto,
        success: function(data) {
          return app.screens.modal('common/success-popup', {
            msg: data.setFlash[0].msg || app.tr("Company was created")
          }, app.screens.back());
        },
        error: function(data) {
          return app.screens.modal('common/info-popup', {
            msg: data.setFlash[0].msg || app.tr("Something went wrong")
          });
        }
      });
    },
    onDomRefresh: function() {
      var _ref;
      if (((_ref = this._data) != null ? _ref.info : void 0) != null) {
        this.$el.find('#name').val(this._data.info.party.Party.name);
        return this.$el.find('#description').val(this._data.info.party.Party.party_info);
      }
    }
  });
});
