define(['app', 'views/item-view', 'underscore', 'text!templates/port.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    data: {
      port: 'port'
    },
    events: {
      'click .js-fish': 'fish',
      'click .js-buy-ship': 'buyShip'
    },
    preprocessData: (function(_this) {
      return function(data) {
        if (data.port != null) {
          data.fisher = data.port.user.UserProfession;
        }
        return data;
      };
    })(this),
    fish: function(event) {
      app.showLoader();
      this.lockUI();
      return app.server.port.fish({
        success: (function(_this) {
          return function(data) {
            var options;
            _this.unlockUI();
            app.hideLoader();
            options = {
              data: data,
              repeat: {
                method: _this.fish,
                context: _this,
                event: event
              }
            };
            _this.app.vent.trigger('port:fishing_completed', {
              data: data
            });
            return _this.app.screens.modal('port/fishing-popup', options);
          };
        })(this),
        error: (function(_this) {
          return function(data) {
            _this.unlockUI();
            app.hideLoader();
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Something went wrong")
            });
          };
        })(this)
      });
    },
    buyShip: function(event) {
      app.showLoader();
      this.lockUI();
      return app.server.port.ship.buy({
        success: function(data) {
          if (data.setFlash != null) {
            return _.forEach(data.setFlash, function(msg) {
              return this.app.screens.modal('common/info-popup', {
                msg: msg.msg
              });
            });
          }
        },
        error: (function(_this) {
          return function(data) {
            _this.unlockUI();
            return app.hideLoader();
          };
        })(this)
      });
    },

    /*
    			Center cloud
     */
    centerCloud: function() {
      var $cloud, $container;
      if ($('.c-cloud').length > 0) {
        $cloud = $('.c-cloud');
        $container = $('.js-current-screen');
        return $cloud.css('margin-top', (($container.height() - $('.c-featured').height()) / 2 - $cloud.height() / 2) / 2);
      }
    },
    onDomRefresh: function() {
      return this.centerCloud();
    }
  });
});
