var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  __hasProp = {}.hasOwnProperty,
  __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; };

define(['underscore', 'views/item-view', 'text!templates/profile.tmpl', 'views/components/clusterize-helper'], function(_, ItemView, template, ClusterizeHelper) {
  var ProfileView;
  ProfileView = (function(_super) {
    __extends(ProfileView, _super);

    function ProfileView() {
      this.updateInventory = __bind(this.updateInventory, this);
      return ProfileView.__super__.constructor.apply(this, arguments);
    }

    ProfileView.prototype.template = template;

    ProfileView.prototype.data = {
      info: 'user.info.short',
      inventory: 'inventory'
    };

    ProfileView.prototype.events = {
      'click .js-item-action': 'itemAction',
      'click .js-buy-slots': 'buySlots',
      'click .c-icon-injury--red': 'injuryPopup',
      'click .c-icon-injury--green': 'energyPopup',
      'click .js-tactics': 'chooseTactics'
    };

    ProfileView.prototype.initialize = function() {
      ProfileView.__super__.initialize.apply(this, arguments);
      this.listenTo(app.vent, 'inventory:inventory_changed', this.updateInventory);
      this.listenTo(app.vent, 'inventory:item_unequipped', (function(_this) {
        return function(event) {
          var _ref, _ref1;
          if (event.data && ((_ref = event.data.itemInfo) != null ? (_ref1 = _ref.ItemType) != null ? _ref1.prestige : void 0 : void 0)) {
            return _this.updatePrestige(-event.data.itemInfo.ItemType.prestige);
          }
        };
      })(this));
      return this.listenTo(app.vent, 'inventory:item_equipped', (function(_this) {
        return function(event) {
          var _ref, _ref1;
          if (event.data && ((_ref = event.data.itemInfo) != null ? (_ref1 = _ref.ItemType) != null ? _ref1.prestige : void 0 : void 0)) {
            return _this.updatePrestige(event.data.itemInfo.ItemType.prestige);
          }
        };
      })(this));
    };

    ProfileView.prototype.updatePrestige = function(diff) {
      var initial, _ref;
      if (((_ref = this._data) != null ? _ref.info : void 0) != null) {
        initial = Number(this._data.info.user.User.prestige) || 0;
        this._data.info.user.User.prestige = Math.max(initial + diff, 0);
        return this.render();
      }
    };

    ProfileView.prototype.updateInventory = function(event) {
      var storage, _ref, _ref1;
      if (!event || (event.data == null)) {
        return;
      }
      storage = event.data;
      if (!this._data || !(((_ref = this._data) != null ? (_ref1 = _ref.inventory) != null ? _ref1.storage : void 0 : void 0) != null)) {
        this._data.inventory.storage = storage;
        return this.render();
      }
    };

    ProfileView.prototype.injuryPopup = function(event) {
      var injured, traumasEffect, _ref;
      if (((_ref = this._data) != null ? _ref.info : void 0) != null) {
        this.lockUI();
        injured = this._data.info.injured;
        traumasEffect = this._data.info.traumasEffect;
        return this.app.screens.modal('common/injury-popup', {
          injured: injured,
          traumasEffect: traumasEffect
        });
      }
    };

    ProfileView.prototype.energyPopup = function(event) {
      var items, recoveryTime, _ref;
      if (((_ref = this._data) != null ? _ref.info : void 0) != null) {
        this.lockUI();
        recoveryTime = this._data.info.user.User.delta_recovery_energy;
        items = this._data.info.eatEffects;
        return this.app.screens.modal('common/energy-popup', {
          items: items,
          recoveryTime: recoveryTime
        });
      }
    };

    ProfileView.prototype.serializeData = function() {
      var data;
      data = ProfileView.__super__.serializeData.apply(this, arguments);
      data.equippedItems = {};
      data.unequippedItems = [];
      if (data && (data.inventory != null) && data.inventory.storage.itemsArray.length !== 0) {
        data.inventory.storage.itemsArray.forEach(function(item) {
          if (item.UserItem.equipped === 1) {
            return data.equippedItems[item.UserItem.equipped_slot] = item;
          } else {
            return data.unequippedItems.push(item);
          }
        });
        data.unequippedItems = _.sortBy(data.unequippedItems, function(a) {
          return a.ItemType.type;
        });
      }
      return data;
    };

    ProfileView.prototype.itemAction = function(event) {
      var itemId;
      itemId = event.currentTarget.getAttribute('data-item-id');
      return app.screens.modal('inventory/popup', {
        inventory: this._data.inventory.storage.itemsArray,
        needReload: false,
        itemId: itemId
      });
    };

    ProfileView.prototype.buySlots = function(event) {
      this.lockUI();
      return app.server.inventory.buySlots({
        size: this._data.inventory.storage.inventorySize + this._data.inventory.expandInfo.size_step,
        success: (function(_this) {
          return function(data) {
            return app.screens.modal('common/success-popup', {
              msg: data.setFlash[0].msg || app.tr("Well done")
            });
          };
        })(this),
        error: function(data) {
          return app.screens.modal('common/info-popup', {
            msg: data.setFlash[0].msg || app.tr("Something went wrong")
          });
        }
      });
    };

    ProfileView.prototype.chooseTactics = function() {
      this.lockUI();
      return app.screens.back((function(_this) {
        return function() {
          return app.screens.dialog('military-base/tactics', {
            areaId: _this.options.areaId,
            postId: _this.options.postId
          });
        };
      })(this));
    };

    ProfileView.prototype.onDomRefresh = function() {
      return [].forEach.call(this.el.querySelectorAll('.js-currency'), function(el) {
        var position, value;
        value = el.innerHTML;
        position = value.indexOf(':') + 1;
        return el.innerHTML = position === 0 ? value : value.slice(position);
      });
    };

    return ProfileView;

  })(ItemView);
  return ProfileView;
});
